@@ -20,7 +20,7 @@ async def reply(client: type, rt: str, msgs: list, disabled: bool):
         "messages": msgs,
         "notificationDisabled": disabled
       })
-      print(r)
+      #print(r) # Dev
       return r
   except Exception as err:
     raise ClientException(err)
